/**
 * @function setupMysql
 */

"use strict";

const execcli = require('execcli'),
    assert = require('assert');

/** @lends setupMysql */
function setupMysql(env, callback) {

    const ROOT_USERNAME = env.ROOT_USERNAME || process.env.ROOT_USERNAME || 'root',
        ROOT_PASSWORD = env.ROOT_PASSWORD || process.env.ROOT_PASSWORD || process.env.MYSQL_ROOT_PASSWORD || '' ;


    const HOST = env.HOST || 'localhost',
        USERNAME = env.USER || env.USERNAME,
        DATABASE = env.DATABASE || env.SCHEMA,
        PASSWORD = env.PASSWORD;

    let sql = _sql(DATABASE, HOST, USERNAME, PASSWORD);

    let cmdBin = 'mysql',
        cmdArgs = _args(ROOT_USERNAME, HOST, ROOT_PASSWORD, sql);

    execcli(cmdBin, cmdArgs, {}, callback);

}

function _sql(database, host, username, password) {
    return `CREATE DATABASE IF NOT EXISTS \`${database}\`; GRANT ALL ON \`${database}\`.* TO \`${username}\`@\`${host}\` IDENTIFIED BY "${password}"`;
}

function _args(username, host, password, sql) {
    let args = [
        '-u', username
    ];
    if (host) {
        args = args.concat('-h', host);
    }
    if (password) {
        args = args.concat('-p' + password);
    }
    args = args.concat({'e': sql});
    return args;
}

module.exports = setupMysql;
